pub enum Error {
}Expand description
This crate’s Error type
Variants
Initialization(Error)
WASMTime initialization failed
Linker(Error)
WASMTime Linker initialization failed
Func(Error)
Setting up linked functions failed.
Module(Error)
WASMTime module instantiation failed
NotFound(String)
WASMTime module instantiation failed
WasiError(Error)
Error originating from wasi_common
WasiStringArray(StringArrayError)
Error originating from wasi_common
IO(Error)
Error originating from std::io::Error
GuestInit
Thrown if the guest’s send function is not exported.
GuestSend
Thrown if the guest’s send function is not exported.
GuestMemory
Thrown if the host has a problem reading the guest’s memory.
NoModule
Thrown if the builder wasn’t provide a module to instantiate with.
AmbiguousModule
Thrown if the builder was provided too many module options.